*******************************************************************************
/* 
PROJECT: SDN banking

OUTPUT OF THIS DO FILE:                                                   
- fig01
	
WRITTEN BY: Gregorio Impavido (gimpavido@imf.org)

WRITTEN WHEN:   02 Feb, 2013
*/
*******************************************************************************

*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/"
* on Q drive
* local base "//data2/EUR/DATA/UNIT/EE/Data/panelchart"
local dta "`base'"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"

*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

use "`dta'/BIS/t6/dta/anx6.dta", clear
global q_end 2012q3


* merge and interpolate GDP
rename time timeq // this is the name for Q obs in the using dbase
merge 1:1 idifs timeq using "`base'/panelchart/gdp/dta/macro-all.dta", keepusing(ngdpd) ///
 nogenerate
replace ngdpd = ngdpd*1000  // original data is in billion, now million
rename timeq time
ipolate ngdp time, by(idifs) gen(ngdpd_ipol)
label var ngdpd_ipol "GDP (USD Million, Linear Interpolation)"
drop ngdpd // we do not need the annual gdp


* SHARE of GDP for ANX vars
foreach var of varlist anx6* {
	bysort idifs (time) : gen double gdp_`var' = 100*`var'/ngdpd_ipol
	local varlab `: variable label `var''
	local varlab1 `: di subinstr("`varlab'",")","/GDP)",.)'
	label var gdp_`var' "`varlab1'"
	}	

* Quarterly rate of changes
* Absolute changes over GDP for ANX vars
local max = q($q_end)-q(2008q2)  


forvalues i=1/`max' {
foreach var of varlist anx6* {
	bysort id (time) : gen double d`i'gdp_`var' = 						///
		100*(`var' - L`i'.`var')/ngdpd_ipol
	local varlab `: variable label `var''
	local varlab1 `: di subinstr("`varlab'",")"," D`i'/GDP)",.)'
	label var d`i'gdp_`var' "`varlab1'"
	}
}


* Clean Names
replace name20char="Macedonia" if word(name20char,1)=="Macedonia,"
replace name20char="Montenegro" if word(name20char,1)=="Montenegro,"
replace name20char="Russia" if word(name20char,1)=="Russian"
replace name20char="Slovak R." if word(name20char,1)=="Slovak"
replace name20char="Czech R." if word(name20char,1)=="Czech"
replace name20char="Serbia" if word(name20char,1)=="Serbia,"
replace name20char="BiH" if word(name20char,1)=="Bosnia"
replace name20char="UAE" if word(name20char,3)=="Emirates"
replace name20char="Bahrain" if word(name20char,1)=="Bahrain,"
replace name20char="Iran" if word(name20char,1)=="Iran,"
replace name20char="Trinidad" if word(name20char,1)=="Trinidad"
replace name20char="Dominican R." if word(name20char,1)=="Dominican"
replace name20char="Venezuela" if word(name20char,1)=="Venezuela,"
replace name20char="UK" if name20char=="United Kingdom"
replace name20char="Taiwan" if word(name20char,1)=="Taiwan"
replace name20char="Korea" if word(name20char,1)=="Korea,"
replace name20char="China" if name20char=="China,P.R.: Mainland"
replace name20char="Azerbaijan" if word(name20char,1)=="Azerbaijan,"
replace name20char="Afghanistan" if word(name20char,1)=="Afghanistan,"
replace name20char="Hong Kong" if name20char=="China,P.R.:Hong Kong"
replace name20char="Bahamas" if word(name20char,1)=="Bahamas,"
replace name20char="BWI" if name20char=="British West Indies"
replace name20char="Antilles (NLD)" if name20char=="Netherlands Antilles"
replace name20char="Cayman I." if word(name20char,1)=="Cayman"
replace name20char="USA" if name20char=="United States"

replace cesee = 0 if word(name20char,1)=="Yugoslavia,"
replace cesee = 0 if name20char=="Serbia & Montenegro"
replace cesee = 0 if name20char=="Estonia" // for this exercise we drop estonia that converted to the Euro
replace cesee = 0 if name20char=="Turkey" 
replace cesee = 0 if name20char=="Russia" 

gen lac   = (reg=="Latin America/Caribbean":reg & ngdpd>20000)
gen asia  = (reg=="Asia & Pacific":reg & ngdpd>20000 & name20char!="Taiwan")

// changes in BANK funding FX adjusted (anx6c_usdass_fx)
gen delta = d`max'gdp_anx6c_usdass_fx
gen delta_cesee = delta if cesee==1
gen delta_lac = delta if lac==1
gen delta_asia = delta if asia==1

outsheet name20char delta_*  using "`out'/wp-f05.txt" if time==q(2012q3) & (delta_cesee<. | delta_lac<. | delta_asia<.), replace

quietly summ delta_cesee if cesee==1 & time==q(2012q3)
local avcesee `: di %9.1fc r(mean)'
quietly summ delta_lac if lac==1 & time==q(2012q3)
local avlac `: di %9.1fc r(mean)'
quietly summ delta_asia if asia==1 & time==q(2012q3)
local avasia `: di %9.1fc r(mean)'

graph bar (asis) delta_cesee delta_lac delta_asia if time==q(2012q3) & (delta_cesee<. | delta_lac<. | delta_asia<.), ///
over(name20char, sort(delta) descending label(labsize(vsmall) angle(45))) ///
nofill ///
bar(1, bstyle(p1bar))														///
bar(2, bstyle(p2bar))														///
bar(3, bstyle(p3bar))														///
/* blabel(bar, format(%2.0f) position(center) color(white) size(vsmall)) */		///
title("Figure 5. Changes in External Positions of BIS Banks During the Crisis", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:2008q2-$q_end change as a percent of GDP, vis-{c 224}-vis banks})", span ring(6) position(11) size(small)) 	///
ytitle(" ") 														///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))						///
text(-13 1 "Av. CESEE: `avcesee'", placement(e) tstyle(smbody))				///
text(-15 1 "Av. LAC: `avlac'", placement(e) tstyle(smbody))					///
text(-17 1 "Av. Asia: `avasia'", placement(e) tstyle(smbody))				///
legend(order(1 2 3) label(1 "CESEE") label(2 "LAC") 					///
	label(3 "Asia") 													///
	cols() rows(1) size(vsmall) symxsize(vsmall) symysize(vsmall) 						///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) 		///
note("Notes: External positions of BIS banks are vis-{c 224}-vis banks and FX adjusted. Averages are unweighted." 							///
"Estonia is not reported as the conversion to the Euro allowed for the repatriation of FX reserve requirements." ///
"Sources: BIS International Statistics (Table 6), IMF WEO and authors' calculations.", size(vsmall) span)														///
graphregion(fcolor(ltbluishgray)) ysize() xsize() plotregion(style(none)) 
graph export "`out'/wp-f05.png", width(2500) replace
	
	
