*******************************************************************************
/* 
PROJECT: SDN banking

OUTPUT OF THIS DO FILE:                                                   
- fig01
	
WRITTEN BY: Gregorio Impavido (gimpavido@imf.org)

WRITTEN WHEN:   02 Feb, 2013
*/
*******************************************************************************

*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/"
* on Q drive
* local base "//data2/EUR/DATA/UNIT/EE/Data/panelchart"
local dta "`base'"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"

*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

import excel "`wkdir'/wp-f06.xlsx", sheet("for GI") cellrange() firstrow clear

replace reg=. if hostcn=="Turkey" | hostcn=="Russia"

replace forsh_asset = forsh_asset2 if forsh_asset2<. // use EBRD, IMF data for CESEE

gen cesee = (reg==3 & !missing(forsh_asset))
gen lac   = (reg==1 & !missing(forsh_asset))
gen asia  = (reg==2 & !missing(forsh_asset))

gen fsh_cesee = forsh_asset if cesee==1
gen fsh_lac = forsh_asset if lac==1 
gen fsh_asia = forsh_asset if asia==1

outsheet hostcntry forsh_asset using "`out'/wp-f06.txt", replace

quietly summ fsh_cesee 
local avcesee `: di %9.1fc r(mean)'
quietly summ fsh_lac 
local avlac `: di %9.1fc r(mean)'
quietly summ fsh_asia 
local avasia `: di %9.1fc r(mean)'

* Asia figure
graph bar (asis) fsh_cesee fsh_lac fsh_asia if hostcntry!="Kosovo" & (fsh_cesee<. | fsh_lac<. | fsh_asia<.), ///
over(hostcntry, sort(forsh_asset) descending label(labsize(vsmall) angle(45))) ///
nofill ///
bar(1, bstyle(p1bar))														///
bar(2, bstyle(p2bar))														///
bar(3, bstyle(p3bar))														///
/* blabel(bar, format(%2.0f) position(center) color(white) size(vsmall)) */		///
title("Figure 6. Banking Sector Foreign Ownership", span ring(7) position(11) size(*0.8)) 	///
subtitle("({it:Percent of host banking sector assets, 2008-09})", span ring(6) position(11) size(small)) 	///
ytitle(" ") 																///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))						///
text(95 80 "Av. CESEE: `avcesee'", placement(e) tstyle(smbody))				///
text(91 80 "Av. LAC: `avlac'", placement(e) tstyle(smbody))					///
text(87 80 "Av. Asia: `avasia'", placement(e) tstyle(smbody))				///
legend(order(1 2 3) label(1 "CESEE") label(2 "LAC") 							///
	label(3 "Asia") 														///
	cols() rows(1) size(vsmall) symxsize(vsmall) symysize(vsmall) 						///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) 		///
note("Sources: EBRD and IMF (for EE countries) and Claessens and Van Horen (2013) (for other countries).", size(vsmall) span)														///
graphregion(fcolor(ltbluishgray)) ysize() plotregion(style(none)) 
graph export "`out'/wp-f06.png", width(2500) replace
