*******************************************************************************
/* 
PROJECT: SDN banking

OUTPUT OF THIS DO FILE:                                                   
- fig01
	
WRITTEN BY: Gregorio Impavido (gimpavido@imf.org)

WRITTEN WHEN:   02 Feb, 2013
*/
*******************************************************************************

*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/"
* on Q drive
* local base "//data2/EUR/DATA/UNIT/EE/Data/panelchart"
local dta "`base'"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"

*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

import excel "`wkdir'/wp-f07-macro.xlsx", sheet("Sheet1") cellrange() firstrow clear
drop if idifs==.
save "`wkdir'/wp-f07-macro.dta", replace
import excel "`wkdir'/wp-f07.xlsx", sheet("for GI") cellrange() firstrow clear
merge 1:1 idifs using "`wkdir'/wp-f07-macro.dta"
drop if _merge==2 | _merge==1
drop cname _merge
foreach var of varlist nfb20*  {
	label var `var' "Net Exports, LCU billion current"
}
foreach var of varlist nfbr20*  {
	label var `var' "Net Exports, LCU billion constant"
}
foreach var of varlist nfi20*  {
	label var `var' "GFCF, LCU billion current"
}
foreach var of varlist nfir20*  {
	label var `var' "GFCF, LCU billion constant"
}
foreach var of varlist ngdp20*  {
	label var `var' "GDP, LCU billion current"
}
foreach var of varlist ngdpr20*  {
	label var `var' "GDP, LCU billion constant"
}
foreach var of varlist ngs20*  {
	label var `var' "National Saving, LCU billion current"
}
label var fe "BIS Foreign Exposures, % GDP"
foreach var of varlist forsh_asset*  {
	label var  `var' "Foreign share of assets, %"
}
label var fc "BIS Foreign Claims, % GDP"

* gen % of GDP
forvalues i=2005/2011 {
	foreach var of varlist nfb`i' nfi`i' ngs`i' {
		gen double `var'_gdp = 100*`var'/ngdp`i'
		local l1 `: variable label `var''
		local l2 `: di subinstr("`l1'","LCU billion","% GDP",1)'
		label var `var'_gdp "`l2'"

	}
	foreach var of varlist nfbr`i' nfir`i' {
		gen double `var'_gdp = 100*`var'/ngdpr`i'
		local l1 `: variable label `var''
		local l2 `: di subinstr("`l1'","LCU billion","% GDP",1)'
		label var `var'_gdp "`l2'"

	}
}


replace reg=. if hostcn=="Turkey" | hostcn=="Russia"

* replace forsh_asset = forsh_asset2 if forsh_asset2<. // use EBRD, IMF data for CESEE

outsheet hostcntry feass08 forsh_asset ld0507bis using "`out'/wp-f08.txt", replace


* scatter
gen cesee = (reg==3 & !missing(feass08, forsh_asset, ld0507bis))
gen lac   = (reg==1 & !missing(feass08, forsh_asset, ld0507bis))
gen asia  = (reg==2 & !missing(feass08, forsh_asset, ld0507bis))

foreach x of varlist cesee lac asia {
quietly reg  feass08 forsh_asset ld0507bis if `x'==1 // the next 5 lines build the caption box
matrix b = e(b)
local b0`x' `: display %5.2f b[1,3]'
local b1`x' `: display %5.2f b[1,1]'
local b2`x' `: display %5.2f b[1,2]'
matrix vcv = e(V)
local tr`x' `: display %5.2f b[1,1]/sqrt(vcv[1,1])'
local r2`x' `: display %5.2f e(r2)'
local caption_`x' "y=`b0`x'' + `b1`x''*x1 + `b2`x''*x2; t1=`tr`x''; R{sup:2}=`r2`x''"
}
quietly reg  feass08 forsh_asset ld0507bis // the next 5 lines build the caption box
matrix b = e(b)
local b0 `: display %5.2f b[1,3]'
local b1 `: display %5.2f b[1,1]'
local b2 `: display %5.2f b[1,2]'
matrix vcv = e(V)
local tr `: display %5.2f b[1,1]/sqrt(vcv[1,1])'
local r2 `: display %5.2f e(r2)'
local caption "y=`b0' + `b1'*x1 + `b2'*x2; t1=`tr'; R{sup:2}=`r2'"

tempvar pos // This controls the positions of the mlabels
gen `pos' = 9 
replace `pos' = 3 if hostcntry=="Lithuania"  // this controls individual points labels (add as needed)
replace `pos' = 3 if hostcntry=="Honduras"  // this controls individual points labels (add as needed)
replace `pos' = 3 if hostcntry=="Chile"  // this controls individual points labels (add as needed)
replace `pos' = 3 if hostcntry=="Brazil"  // this controls individual points labels (add as needed)
replace `pos' = 3 if hostcntry=="Colombia"  // this controls individual points labels (add as needed)
replace `pos' = 3 if hostcntry=="Dominican R."  // this controls individual points labels (add as needed)
replace `pos' = 3 if hostcntry=="Guatemala"  // this controls individual points labels (add as needed)
replace `pos' = 3 if hostcntry=="Thailand"  // this controls individual points labels (add as needed)
replace `pos' = 3 if hostcntry=="Philippines"  // this controls individual points labels (add as needed)
replace `pos' = 12 if hostcntry=="Vietnam"  // this controls individual points labels (add as needed)

* now we do partition regressions
quietly reg  feass08 forsh_asset ld0507bis
quietly reg  feass08              ld0507bis if e(sample)
predict uy if e(sample), res
quietly reg  forsh_asset         ld0507bis if e(sample)
predict ux if e(sample), res

graph twoway ///
(scatter uy ux if cesee==1, mlabel(hostcntry) mlabvposition(`pos') mlabsize(vsmall)) ///
(scatter uy ux if lac==1, mlabel(hostcntry) mlabvposition(`pos') mlabsize(vsmall)) ///
(scatter uy ux if asia==1, mlabel(hostcntry) mlabvposition(`pos') mlabsize(vsmall)) ///
(lfit uy ux if cesee==1, lstyle(p1))  ///
(lfit uy ux if lac==1, lstyle(p2))  	///
(lfit uy ux if asia==1, lstyle(p3)) 	///
(lfit uy ux, lstyle(p4)), 			///
title("Figure 8. Foreign Ownership and Funding Controlling for Deposits", ///
	span ring(7) position(11) size(*0.8)) 									///
subtitle("({it:2005-08})", 												///
	span ring(6) position(11) size(small)) 									///
ytitle("e(Foreign Funding (% Bank Assets) | LD Ratio)") 											///
yscale() 																	///
ylabel(, ang(h) gstyle(major) glcolor(gs12))								///
xtitle("e(Foreign Ownership (% Bank Assets) | LD Ratio)") 									///
xscale() xlabel() 														///
legend(order(1 2 3 7) label(1 "CESEE") label(2 "LAC") label(3 "Asia") label(7 "FULL sample") 	///
	cols() rows(1) size(vsmall) symxsize(vsmall) symysize(vsmall) 						///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) 		///
note("Sources: BIS, Claessens and Van Horen (2013), EBRD, IMF WEO, WB FINSTAT and authors' calculations.", size(vsmall) span)														///
caption("CESEE: `caption_cesee'" "LAC: `caption_lac'" "Asia:  `caption_asia'" "FULL: `caption'", ///
/* caption("`caption'", */ ///
	ring(0) position(11) size(vsmall) box margin(t+1 r+1)) ///
graphregion(fcolor(ltbluishgray)) ysize() plotregion(style(none)) 
graph export "`out'/wp-f08.png", width(2500) replace
