*******************************************************************************
/* 
PROJECT: BIS DATA                                            

OUTPUT OF THIS DO FILE:                                                   
- uses data from anx6a.csv and anx6b.csv to build a panel summary
	
WRITTEN BY: Gregorio Impavido (gimpavido@imf.org)

WRITTEN WHEN:   10 May, 2012
*/
*******************************************************************************

*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on Q drive
* local base "//data2/EUR/DATA/UNIT/EE/Data/panelchart"

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/panelchart"
local dta "`base'/dta"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"


global q_start 2000q1
global q_end 2012q2

*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

use "\\data4\users2\GIMPAVIDO\My Documents\Stata\Data\Loan Deposit\dta\CESEE Loans Deposits.dta", clear

replace name20char="Czech R." if word(name20char,1)=="Czech" 
replace name20char="BiH" if word(name20char,1)=="Bosnia" 
replace name20char="Serbia" if word(name20char,1)=="Serbia," 
replace name20char="Macedonia" if word(name20char,1)=="Macedonia,"
replace name20char="Russia" if word(name20char,1)=="Russian"
replace name20char="Slovak R." if word(name20char,1)=="Slovak" 
replace name20char="Montenegro" if word(name20char,1)=="Montenegro," 
replace name20char="Kosovo" if word(name20char,1)=="Kosovo," 

drop if inlist(name20char,"Kosovo","Montenegro")  // no data
drop if name=="Russia" | name=="Turkey"
egen double tot_l = rowtotal(v_2 v_4 v_6 v_8)
gen double share = 100*(v_2+v_6)/tot_l

foreach var of varlist v_2 v_4 v_6 v_8 v_10 tot_l {
	gen double `var'_gdp = 100*`var'/ngdp
	local varlab `: variable label `var''
	local varlab1 `: di subinstr("`varlab'","LCU Million","% GDP",.)'
	label var `var'_gdp "`varlab1'"
}

egen double fx_gdp = rowtotal(v_2_gdp v_6_gdp)

*******************************************************************************
****************************** GRAPH *****************************
*******************************************************************************
outsheet time name20char v_2_gdp v_6_gdp v_4_gdp v_8_gdp using "`out'/wp-f09.txt" if time==m(2012m9), replace
graph bar (asis) v_2_gdp v_6_gdp v_4_gdp v_8_gdp if time==m(2012m9), 		///
over(name20char, sort(fx_gdp) descending label(labsize(small) angle(45)))	///
stack 																		///
bar(1, bstyle(p1bar))														///
bar(2, bstyle(p1bar) fintensity(inten40) lcolor())							///
bar(3, bstyle(p2bar))														///
bar(4, bstyle(p2bar) fintensity(inten40) lcolor())							///
blabel(bar, format(%2.0f) position(center) color(white) size(vsmall))		///
yline()																		///
title("Figure 9. Importance of FX Loans", span ring(7) position(11) size(*0.8)) ///
subtitle("({it:Percent of GDP, end 2012 1/})", 								///
	span ring(6) position(11) size(small)) 									///
ytitle() 																	///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))						///
legend(order(1 3 2 4) label(1 "FX Loans (Corporate)") label(2 "FX Loans (Household)") ///
	label(3 "LCU Loans (Corporate)") label(4 "LCU Loans (Household)") 		///
	cols() rows(2) size(vsmall) symxsize(vsmall) symysize(vsmall) 			///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) ///
note("Note: 1/ FX indexed LCU loans are not included in FX data." 			///
"Sources: IMF IFS and authors' calculations.", size(vsmall) span)			///
graphregion(fcolor()) plotregion(style(none))	
graph export "`out'/wp-f09.png", width(2500) replace

*******************************************************************************
************************************* END *************************************
*******************************************************************************
