*******************************************************************************
/* 
PROJECT: SDN banking

OUTPUT OF THIS DO FILE:                                                   
- fig01
	
WRITTEN BY: Gregorio Impavido (gimpavido@imf.org)

WRITTEN WHEN:   02 Feb, 2013
*/
*******************************************************************************

*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/"
* on Q drive
* local base "//data2/EUR/DATA/UNIT/EE/Data/panelchart"
local dta "`base'"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"

*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

import excel "`wkdir'/wp-f11.xlsx", sheet("stata") cellrange() firstrow clear
outsheet using "`out'/wp-f11.txt", replace

drop if cname=="Turkey" | cname=="Russia"
/*
gen dep_cesee = dep_gdp_if cesee==1
gen a_cesee = a_gdp_if cesee==1
gen dep_lac = dep_gdp_if cesee==0
gen a_lac = a_gdp_if cesee==0
*/

* scatter
tempvar pos // This controls the positions of the mlabels
gen `pos' = 3 
replace `pos' = 9 if cname=="Chile"  // this controls individual points labels (add as needed)
replace `pos' = 9 if cname=="Bolivia"  // this controls individual points labels (add as needed)
replace `pos' = 9 if cname=="Uruguay"  // this controls individual points labels (add as needed)
replace `pos' = 12 if cname=="Venezuela"  // this controls individual points labels (add as needed)
replace `pos' = 9 if cname=="Dominican R."  // this controls individual points labels (add as needed)

replace `pos' = 9 if cesee==1
replace `pos' = 2 if cname=="Kazakhstan"  // this controls individual points labels (add as needed)
replace `pos' = 3 if cname=="Bulgaria"  // this controls individual points labels (add as needed)
replace `pos' = 3 if cname=="Romania"  // this controls individual points labels (add as needed)
replace `pos' = 4 if cname=="Macedonia"  // this controls individual points labels (add as needed)
replace `pos' = 10 if cname=="Poland"  // this controls individual points labels (add as needed)
replace `pos' = 10 if cname=="Hungary"  // this controls individual points labels (add as needed)
replace `pos' = 12 if cname=="Latvia"  // this controls individual points labels (add as needed)


graph twoway ///
(scatter pfa_gdp2009 pfdep_ba if cesee==1, mlabel(cname) mlabvposition(`pos') mlabsize(vsmall) ) ///
(scatter pfa_gdp2009 pfdep_ba if cesee==0, mlabel(cname) mlabvposition(`pos') mlabsize(vsmall) ), ///
title("Figure 11. The Importance of Pension Funds in Bank Funding", ///
	span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:2009, percent})", 														///
	span ring(6) position(11) size(small)) 	///
ytitle("Assets of Pension Funds (over GDP)") 													///
yscale() 																			///
ylabel(, ang(h) gstyle(major) glcolor(gs12))										///
xtitle("Deposits of Pension Funds (over Banking Sector Assets)") 											///
xscale() xlabel() 																	///
legend(order(1 2) label(1 "CESEE") label(2 "LAC")  	///
	cols() rows(1) size(vsmall) symxsize(vsmall) symysize(vsmall) 						///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) 		///
note("Sources: AIOS, National authorities, World Bank Global Development Database and authors' calculations.", size(vsmall) span)														///
caption("", ///
	ring(0) position(11) size(vsmall) box margin(t+1 r+1)) ///
graphregion(fcolor(ltbluishgray)) ysize() plotregion(style(none)) 
graph export "`out'/wp-f11.png", width(2500) replace
