*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/CESEE bank database/BScope2012"
local dta "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"


/*
* on Q drive
local base "//data2/EUR/DATA/UNIT/EE/Data/CESEE bank database/BScope2012"
local dta "`base'/dta"
local wkdir "O:\DATA\UNIT\EE\Papers\2012Q4 - banking in CESEE\SDN"
local out  "O:\DATA\UNIT\EE\Papers\2012Q4 - banking in CESEE\SDN"
*/

*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

import excel "`dta'/wp-f13.xlsx", sheet("Results") firstrow clear
rename BvDIDNumbers bvd_id
rename TotalAssetsthUSD2011 bvd_al12
rename Index bvd_idx
rename Countrycode bvd_ciso2
rename BankName bvd_name

* fix serbian banks which are actually in Kosovo
replace bvd_ciso2="KV" if City=="PRISTINA" | City=="PRISHTINA"
replace bvd_id = subinstr(bvd_id,"RS","KV",1)  if bvd_ciso2=="KV"

* keep on statement per bank (the largest)
gsort bvd_id -bvd_al12
by bvd_id : gen rank = _n
keep if rank==1
save "`out'/wp-f13.dta", replace

local dta "`base'/dta"
use "`dta'/bvds-guos-all.dta", clear

* prepare sample 
// keep only 2011 non missing data, GUOs that are bank, and ONLY WESTERN country GUOS
keep if guo_bank==1 & time==2011  & guo_al12<.  &  ///
 (inlist(guo_isr3,"AT","IT","FR","DE","BE","NL","SE","NO","FI") | ///
	inlist(guo_isr3,"US","ES","PT","IR","DK","GR","GB"))

keep bvd_id guo_isr1 guo_isr3 guo_al12

merge 1:1 bvd_id using "`out'/wp-f13.dta", keepusing(bvd_al12)

keep if _merge==3

// change data from Thou to billion
foreach var of varlist guo_al12 bvd_al12 {
	replace `var' = `var'/1000000
	local lbl `: variable label `var''
	local lbl1 = subinstr("`lbl'","th ", "billion ",1)
	label var `var' "`lbl1'"
	}
	

// gen share of subsiddiary assets in total gruop assets
bysort guo_isr1 : egen double totsub = total(bvd_al12)	// total subsidiary assets per parent
gen double subsh = 100*totsub/guo_al12
label var subsh "Share of subs assets in total group assets"
drop totsub bvd_al12

* generate short bank names
gen bname = guo_isr1
replace bname = "Citigroup" if guo_isr1=="Citigroup Inc"
replace bname = "Swedbank" if guo_isr1=="Swedbank AB"
replace bname = "SEB" if guo_isr1=="Skandinaviska Enskilda Banken AB"
replace bname = "Nordea" if guo_isr1=="Nordea Bank AB (publ)"
replace bname = "Home Credit" if guo_isr1=="Home Credit BV"
replace bname = "ING" if guo_isr1=="ING Bank NV"
replace bname = "FGA Capital" if guo_isr1=="FGA Capital SPA"
replace bname = "Banco Veneto" if guo_isr1=="Veneto Banca scpa"
replace bname = "Banco Popolare" if guo_isr1=="Banco Popolare"
replace bname = "Intesa Sanpaolo" if guo_isr1=="Intesa Sanpaolo"
replace bname = "UniCredit" if guo_isr1=="UniCredit SpA"
replace bname = "RCI" if guo_isr1=="RCI Banque"
replace bname = "Socit Gnrale" if guo_isr1=="Socit Gnrale"
replace bname = "Crdit Agricole" if guo_isr1=="Crdit Agricole S.A."
replace bname = "BNP" if guo_isr1=="BNP Paribas"
replace bname = "BBVA" if guo_isr1=="Banco Bilbao Vizcaya Argentaria SA"
replace bname = "Santander" if guo_isr1=="Banco Santander SA"
replace bname = "ProCredit" if guo_isr1=="ProCredit Holding AG"
replace bname = "Wstenrot" if guo_isr1=="Wstenrot & Wrttembergische"
replace bname = "Bayerische" if guo_isr1=="Bayerische Landesbank"
replace bname = "DZ Bank" if guo_isr1=="DZ Bank AG-Deutsche Zentral-Genossenschaftsbank"
replace bname = "Commerzbank" if guo_isr1=="Commerzbank AG"
replace bname = "Deutsche Bank" if guo_isr1=="Deutsche Bank AG"
replace bname = "KBC" if guo_isr1=="KBC Bank NV"
replace bname = "Bank Styria" if guo_isr1=="Steiermrkische Bank und Sparkassen AG-Bank Styria"
replace bname = "Hypo Alpe-Adria" if guo_isr1=="Hypo Alpe-Adria Bank International AG-Hypo Alpe-Adria-Group"
replace bname = "BAWAG PSK" if substr(guo_isr1,1,8)=="Bank fr"
replace bname = "Volksbank" if guo_isr1=="Volksbanken Holding regGenmbH"
replace bname = "Raiffeisen - RZB" if guo_isr1=="Raiffeisen Zentralbank Oesterreich AG - RZB"
replace bname = "Erste" if guo_isr1=="Erste Group Bank AG"
replace bname = "BKS" if guo_isr1=="BKS Bank AG"
replace bname = "Kaerntner" if guo_isr1=="Kaerntner Sparkasse"
replace bname = "BCP" if substr(guo_isr1,1,21)=="Banco Comercial Portu"
replace bname = "Hypo-Bank Burgenland" if substr(guo_isr1,1,15)=="Hypo-Bank Burge"
replace bname = "Warburg" if guo_isr1=="M.M. Warburg & CO Gruppe KGaA"
replace bname = "NBG" if guo_isr1=="National Bank of Greece SA"
replace bname = "Rabobank" if guo_isr1=="Rabobank Nederland-Rabobank Group"
replace bname = "RBS" if guo_isr1=="Royal Bank of Scotland Group Plc (The)"
replace bname = "Goldman Sachs" if substr(guo_isr1,1,13)=="Goldman Sachs"
replace bname = "Eurobank Ergasias" if substr(guo_isr1,1,17)=="Eurobank Ergasias"
replace bname = "Piraeus Bank" if substr(guo_isr1,1,12)=="Piraeus Bank"
replace bname = "Alpha Bank" if substr(guo_isr1,1,10)=="Alpha Bank"
replace bname = "HSBC" if substr(guo_isr1,1,4)=="HSBC"

drop if substr(bvd_id,1,2)=="RU"  // restrict to EE countries
drop if substr(bvd_id,1,2)=="TR"  // restrict to EE countries

* prepare labels for y axis
gen bname2 = bname + " (" + guo_isr3 + ")"
bysort bname2 : gen n = _n
keep if n==1

** graph
* prepare labels
capture label drop blbl
capture drop *enc
gsort -guo_al12 // you need ascending order to show in descending order in graph below
gen bname_enc = _n
* gen cname_enc = _n
forvalues i = 1/`= _N' {
	di bname[`i'] " (" guo_isr3[`i'] ")"
	label define blbl `i' "`: di bname2[`i']'", add
	}
label value bname_enc blbl

graph twoway 																///
(bar guo_al12 bname_enc, barw(0.7) horiz xaxis(1) 							///
	xlabel(, format(%9.0fc) grid gstyle(major) axis(1))						///
	ylabel(1(1)`= _N', valuelabel labsize(tiny) notick ang(h) axis(1))) 	///
(scatter bname_enc  subsh, msymbol() mcolor() msize(small) xaxis(2)			///
	xlabel(, format(%9.0fc) grid gstyle(major) axis(2))						///
	ylabel(1(1)`= _N', valuelabel labsize(tiny) notick ang(h) axis(1))),	///
xline(30, axis(2))															///
ytitle("")																	///
xtitle("", axis(1))															///
xtitle("", axis(2))															///
title("Figure 13. Share of CESEE Subsidiaries in Parent Consolidated Assets",			///
	span position(11) size(*0.8)) /* play with size depending on length */	///
subtitle("({it:2011})",	span ring(6) position(11) size(small)) 				///
legend(order(2 1) label(1 "Consolidated Assets (USD billion, bottom)") 		///
	label(2 "Subsidiary Share (percent, top)") 								///
	cols(1) rows(2) ring(0) bplacement(2.5)									///
	symxsize(vsmall) symysize(vsmall) size(vsmall) 							///
	region(fcolor(ltbluishgray))) 											///
note("Notes: Bankscope did not contain 2011 data for few small subsidiaries at the time of the download." 											///
	"Sources: Bankscope and authors' calculations.", size(*0.8) span)		///
caption("", ring(0) position(4) size(vsmall) box) 							///
graphregion(fcolor()) ysize() plotregion(style(none))						
graph export "`out'/wp-f13.png", width(2500) replace

outsheet bname_enc subsh guo_al12 using "`out'/wp-f13.txt", replace
