*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/panelchart"
local dta "`base'/dta"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"


*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

global q_end 2012q2

*******************************************************************************
********************************* SCATTER GRAPHS ******************************
*******************************************************************************
local where `: di subinstr(`"`base'"', "panelchart", "BIS/t9",1)'
use "`where'/dta/hanx9.dta", clear

* merge quarterly GDP
rename time timeq // this is the name for Q obs in the using dbase
merge 1:1 idifs timeq using "`base'/gdp/dta/macro-all.dta", keepusing(ngdpd) nogenerate
replace ngdpd = ngdpd*1000  // original data is in billion, now million
rename timeq time
ipolate ngdpd time, by(name20bis) gen(ngdpd_ipol) epolate

drop hanx9b_usd11  // no need for EU aggregate
replace cesee=0 if name20char=="Turkey" | name20char=="Russian Federation"  // we are not considering Turkey and Russia
keep if cesee==1 & time==q($q_end)
keep time idifs name20char isocode3char cesee ngdpd_ipol hanx9b*
drop if name20char=="Yugoslavia, SFR"
drop cesee

foreach var of varlist hanx9b* {
	replace `var' = . if `var'==0 // you need this to ensure good order of labels in scatter	
	local name1 `: variable label `var''
	local name2 = word(`"`name1'"',1)
	rename `var' `name2'
	}

/*
* generate share of total claims
egen rtotal = rowtotal(Australian-US)
egen total_all = total(rtotal)
foreach var of varlist Australian-US {
	egen tot_`var' = total(`var')
	gen share_`var' = tot_`var'/total_all
	}
*/
	
rename Austrian Austria
rename Italian Italy
rename French France
rename German Germany
rename Belgian Belgium
rename Dutch Netherlands
rename Swedish Sweden
rename US USA

order time idifs name20char iso* ngdpd_ipol Austria Belgium France Germany Italy Netherlands Sweden USA

egen double Other = rowtotal(Australian- Turkish)
label var Other "Other Claims by Recipient Country (USD Million)"	
egen double Total_cli = rowtotal(Austria- Turkish)
label var Total_cli "Total Claims by Recipient Country (USD Million)"
egen double Total_cl = total(Total_cli)
label var Total_cl "Total Claims in the Region (USD Million)"
egen double gdp_tot = total(ngdpd_ipol)
label var gdp_tot "Total GDP in the Region (USD Million)"

* gen total claims by reporting country;shares in country GDP and shares inreporting country claims
foreach var of varlist Austria- Turkish Other {
	egen double `var'_cl = total(`var')
	local lbl1 `: variable label `var''
	local lbl2 `: di subinstr("`lbl1'","USD Million","USD Million, Total Claims",1)'
	label var `var'_cl "`lbl2'"

	gen `var'_gdp = 100*`var'/ngdpd_ipol
	local lbl1 `: variable label `var''
	local lbl2 `: di subinstr("`lbl1'","USD Million","share of GDP",1)'
	label var `var'_gdp "`lbl2'"
	
	gen `var'_cli = 100*`var'/`var'_cl
	local lbl1 `: variable label `var''
	local lbl2 `: di subinstr("`lbl1'","USD Million","Share of Reporting Country Claims",1)'
	label var `var'_cli "`lbl2'"
	}
	
* gen scatterpots by reporting country

foreach var of varlist Austria- USA Other {
	* gen hhis
	gen double `var'_hhicli = 10000*(`var'_cli/100)^2
	replace `var'_hhicli = sum(`var'_hhicli)
	quietly summ `var'_hhicli 
	local hhicli : display %5.0f r(max)
	local capcli "HHI = `hhicli'"
			
	tempvar ciso3
	* next 3 lines prepares the x labels sorted according to `var'_gdp in reverse order 
	egen `ciso3' = axis(`var'_gdp), label(isocode3char)  reverse
	quietly summ `ciso3'
	local last = r(N) // this to get the right number of xlabels

	outsheet `var'_gdp `ciso3' `var'_cli using "`out'/wp-f14-`var'.txt", replace
	
	graph twoway 															///
	(bar `var'_gdp `ciso3', barwidth(0.7) yaxis())							///
	(scatter `var'_cli `ciso3', yaxis() msize(*0.7)), 						///
	ylabel(#3, format() ang(h) gstyle(major) glcolor(gs12) axis())			///
	ylabel(#3, format() ang(h) gstyle(major) glcolor(gs12) axis())			///
	xlabel(1(1)`last', valuelabel ang(90) labsize(*0.7))					///
	title("`var'", size(*0.8)) xtitle(" ") note(" ") 						///
	ytitle(" ", axis()) 													///
	ytitle(" ", axis()) 													///
	legend(order(1 2) label(1 "Percent of Host Country GDP")				///
		label(2 "Percent of Reported Claims") 								///
		span bexpand symxsize(vsmall) size(vsmall) 							///
		region(fcolor(ltbluishgray)))										///
	caption("`capcli'", ring(0) position(2) size(small) margin() ) 			///
	graphregion(margin() fcolor()) ysize()	plotregion(style(none))	nodraw	///
	saving("`out'/scat_`var'.gph", replace) 
	}

*******************************************************************************
******************************* ASSEMBLE PANELS *******************************
*******************************************************************************
* combine individual country scatter graphs
local filelist : dir "`out'"  files "scat*.gph"
	// need all lower letters if not grc1leg does not work 
cd "`out'"  // otherwise the next command does not work
grc1leg `filelist',															///
cols(3) rows(3) iscale()  imargin(l=-8 r=-0 t=-2 b=-12) fysize() ycommon	///
title("Figure 14. Importance of Foreign Banks in CESEE",		///
	span position(11) size(*0.8)) /* play with size depending on length */	///
subtitle("({it:2012q2 foreign claims of BIS banks})", 						///
	span ring(6) position(11) size(small)) 									///
note("Note: Claim data is on an immediate borrower basis (where the actual borrower resides) and non-FX adjusted."  ///
	"Only largest 8 countries with a share of at least 5.3 percent of total foreign claims in the region are listed." ///
	"Sources: BIS Consolidated Statistics (Table 9), IMF WEO, and authors' calculations.", size(*0.8) span)		///
graphregion(fcolor()) ysize() plotregion(style(none))
graph export "`out'/wp-f14.png", width(2500) replace

* clean garbage
local filelist : dir "`out'" files "scat_*.gph"
foreach file of local filelist {
	erase "`out'/`file'"
}

