*******************************************************************************
/* 
PROJECT: IMPAVIDO RUDOLPH RUGGERONE BANKING WP                                            

OUTPUT OF THIS DO FILE:                                                   
- RUDOLPH GRAPHS
	
WRITTEN BY: Gregorio Impavido (gimpavido@imf.org)

WRITTEN WHEN:   05 February, 2113
*/
*******************************************************************************

*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on Q drive
* local base "//data2/EUR/DATA/UNIT/EE/Data/panelchart"

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local dta "`base'"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"


*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

************************************ EE NBFI % gdp ************************************
import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("NBFI Market as % of GDP") cellrange(R6:V17) firstrow clear
foreach var of varlist 	Ins Inv Pen Tot {
	replace `var' = 100*`var'
	}
outsheet using "`out'/wp-f16.txt", replace

graph bar (asis)  Pen Ins Inv, 		///
over(cname, sort(Tot) descending label(labsize(small) angle(45)))						///
stack 																					///
bar(1, bstyle(p1bar))																	///
bar(2, bstyle(p2bar))																	///
bar(3, bstyle(p3bar))																	///
blabel(bar, format(%2.0f) position(center) color(white) size(vsmall))					///
title("Figure 16. Assets Under Management by NBFIs", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:Percent of GDP, end 2011})", 											///
	span ring(6) position(11) size(small)) 												///
ytitle() 																				///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))									///
legend(order(1 2 3) label(1 "Pension Funds 1/") label(2 "Insurance Companies") 			///
	label(3 "Investment Funds")										 					///
	rows(1) size(vsmall) symxsize(vsmall) symysize(vsmall)								///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) 		///
note("Note: 1/ Second and third pillars." 												///
"Sources: National authorities and authors' calculations.", size(vsmall) span)			///
graphregion(fcolor()) plotregion(style(none))	
graph export "`out'/wp-f16.png", width(2500) replace

************************************ Chile ************************************
import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("Chile Statistics") cellrange(T6:W33) firstrow clear
foreach var of varlist 	Mut Ins Pen {
	replace `var' = 100*`var'
	}
outsheet using "`out'/wp-f17.txt", replace

graph twoway line Pen Ins Mut time, 													///
title("Figure 17. Assets Under Management by NBFIs in Chile", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:Percent of GDP, 1985-2011})", 											///
	span ring(6) position(11) size(small)) 												///
ytitle() 																				///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))									///
legend(order(1 2 3) label(1 "Pension Funds") label(2 "Insurance Companies") 			///
	label(3 "Mutual Funds")										 						///
	rows(1) size(vsmall) symxsize(vsmall) symysize(vsmall)								///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) 		///
note("Sources: National authorities and authors' calculations.", size(vsmall) span)		///
graphregion(fcolor()) plotregion(style(none))	
graph export "`out'/wp-f17.png", width(2500) replace

************************************ EE Insurance mkt share ************************************
import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("Insurance product marketshare") cellrange(E4:G14) firstrow clear
foreach var of varlist 	Life Non {
	replace `var' = 100*`var'
	}
outsheet using "`out'/wp-f18.txt", replace

graph bar (asis)  Life Non, 															///
over(cname, sort(Life) descending label(labsize(small) angle(45)))						///
stack 																					///
bar(1, bstyle(p1bar))																	///
bar(2, bstyle(p2bar))																	///
blabel(bar, format(%2.0f) position(center) color(white) size(vsmall))					///
title("Figure 18. Importance of Life Insurance Business", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:Percent of total gross premium income, end 2011})", 						///
	span ring(6) position(11) size(small)) 												///
ytitle() 																				///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))									///
legend(order(1 2) label(1 "Life") label(2 "Non-Life") 									///
	rows(1) size(vsmall) symxsize(vsmall) symysize(vsmall)								///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) 		///
note("Sources: National authorities and authors' calculations.", size(vsmall) span)		///
graphregion(fcolor()) plotregion(style(none))	
graph export "`out'/wp-f18.png", width(2500) replace

************************************ EE NBF Inv Portfolio ************************************
import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("NBFI Portfolio Structure") cellrange(F62:M72) firstrow clear
foreach var of varlist 	Equity-Other {
	replace `var' = 100*`var'
	}
outsheet using "`out'/wp-f19.txt", replace	
	
graph bar (asis)  Equity-Other, 		///
over(cname, sort(Equity) descending label(labsize(small) angle(45)))					///
stack 																		///
bar(1, bstyle(p1bar))														///
bar(2, bstyle(p2bar))														///
bar(3, bstyle(p3bar))														///
bar(4, bstyle(p4bar))														///
bar(5, bstyle(p5bar))														///
bar(6, bstyle(p6bar))														///
bar(7, bstyle(p7bar))														///
blabel(bar, format(%2.0f) position(center) color(white) size(vsmall))		///
title("Figure 19. Investment Portfolio of NBFIs", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:Percent of total AUM, end 2011})", 								///
	span ring(6) position(11) size(small)) 									///
ytitle() 																	///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))									///
legend(order(1 2 3 4 5 6 7) 												///
	label(1 "Equity") label(2 "Debt") label(3 "Mixed") 						///
	label(4 "Money mkt.") label(5 "Deposits") label(6 "Fin. Intermed. 1/") ///
	label(7 "Other") ///
	rows(2) size(vsmall) symxsize(vsmall) symysize(vsmall) 						///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) ///
note("Notes: 1/ Financial intermediation are assets held by insurance companies related to loans, including loans guaranteed by mortgages." ///
"Sources: National authorities and authors' calculations.", size(vsmall) span)														///
graphregion(fcolor()) plotregion(style(none))	
graph export "`out'/wp-f19.png", width(2500) replace

************************************ EE corporate bond issuance ************************************
import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("Corporate Bond Issuance") cellrange(D7:E16) firstrow clear
outsheet using "`out'/wp-f20.txt", replace	
	
graph bar (asis)  USD, 		///
over(cname, sort(USD) descending label(labsize(small) angle(h)))						///
stack 																					///
bar(1, bstyle(p1bar))																	///
title("Figure 20. Size of Corporate Bond Issuance", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:2010-12 average, USD million})", 										///
	span ring(6) position(11) size(small)) 												///
ytitle("") 																				///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))									///
legend(off) 																			///
note("Sources: Bloomberg.", size(vsmall) span)											///
graphregion(fcolor()) plotregion(style(none))	
graph export "`out'/wp-f20.png", width(2500) replace

************************************ EE NBFI mkt value ************************************
import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("NBFI Market Asset Values") cellrange(F4:N14) firstrow clear
outsheet using "`out'/wp-f21.txt", replace	

graph bar (asis)  Equity-Other, 		///
over(cname, sort(TOTAL) descending label(labsize(small) angle(45)))					///
stack 																		///
bar(1, bstyle(p1bar))														///
bar(2, bstyle(p2bar))														///
bar(3, bstyle(p3bar))														///
bar(4, bstyle(p4bar))														///
bar(5, bstyle(p5bar))														///
bar(6, bstyle(p6bar))														///
bar(7, bstyle(p7bar))														///
/* blabel(bar, format(%2.0f) position(center) color(white) size(vsmall))	*/	///
title("Figure 21. Assets Under Management by NBFIs", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:EUR million, end 2011})", 								///
	span ring(6) position(11) size(small)) 									///
ytitle("") 																	///
ylabel(, format(%9.0fc) ang(h) gstyle(major) glcolor(gs12))						///
legend(order(1 2 3 4 5 6 7) 												///
	label(1 "Equity") label(2 "Debt") label(3 "Mixed") 						///
	label(4 "Money mkt.") label(5 "Deposits") label(6 "Fin. Intermed.") 	///
	label(7 "Other") ///
	rows(2) size(vsmall) symxsize(vsmall) symysize(vsmall) 						///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) ///
note("Sources: National authorities.", size(vsmall) span)														///
graphregion(fcolor()) plotregion(style(none))	
graph export "`out'/wp-f21.png", width(2500) replace


************************************ EE market cap ************************************
import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("Market Cap in CEE") cellrange(C11:D17) firstrow clear
outsheet using "`out'/wp-f22.txt", replace	

graph bar (asis)  USD, 		///
over(cname, sort(USD) descending label(labsize(small) angle(h)))					///
stack 																		///
bar(1, bstyle(p1bar))														///
blabel(bar, format(%9.0fc) position(center) color(white) size(vsmall))		///
title("Figure 22. Market Capitalization of Bourses in the Region", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:USD billion, end 2011})", 								///
	span ring(6) position(11) size(small)) 									///
ytitle("") 																	///
ylabel(, format(%9.0fc) ang(h) gstyle(major) glcolor(gs12))						///
legend(off) ///
note("Sources: Bloomberg.", size(vsmall) span)														///
graphregion(fcolor()) plotregion(style(none))	
graph export "`out'/wp-f22.png", width(2500) replace


************************************ EE appendix panel ************************************
import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("Pension Funds") cellrange(D33:H43) firstrow clear
* destring *, replace
foreach var of varlist 	Equity-Other {
	replace `var' = 100*`var'
	}
outsheet using "`out'/wp-f23a.txt", replace	
graph bar (asis)  Equity-Other, 		///
over(cname, sort(Equity) descending label(labsize(small) angle(h)))					///
stack 																		///
bar(1, bstyle(p1bar))														///
bar(2, bstyle(p2bar))														///
bar(3, bstyle(p5bar))														///
bar(4, bstyle(p7bar))														///
blabel(bar, format(%2.0f) position(center) color(white) size(vsmall))		///
title("Pension Funds", span ring(7) position() size(*0.8)) 			///
ylabel(, format(%9.0fc) ang(h) gstyle(major) glcolor(gs12))						///
legend(order(1 2 3 4) 												///
	label(1 "Equity") label(2 "Debt") label(3 "Deposits") ///
	label(4 "Other") ///
	rows(1) size(small) symxsize(vsmall) symysize(vsmall) 						///
	ring() position() region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) ///
graphregion(fcolor()) plotregion(style(none)) ///
saving("`out'/hr - s3 f8a.gph", replace)

import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("Insurance Investments") cellrange(D3:H13) firstrow clear
* destring *, replace
foreach var of varlist 	Equity-Other {
	replace `var' = 100*`var'
	}
outsheet using "`out'/wp-f23b.txt", replace	

graph bar (asis)  Equity-Other, 		///
over(cname, sort(Equity) descending label(labsize(small) angle(h)))					///
stack 																		///
bar(1, bstyle(p1bar))														///
bar(2, bstyle(p2bar))														///
bar(3, bstyle(p6bar))														///
bar(4, bstyle(p7bar))														///
blabel(bar, format(%2.0f) position(center) color(white) size(vsmall))		///
title("Insurance", span ring(7) position() size(*0.8)) 			///
ylabel(, format(%9.0fc) ang(h) gstyle(major) glcolor(gs12))						///
legend(order(1 2 3 4) 												///
	label(1 "Equity") label(2 "Debt") label(3 "Fin. Intermed. 1/") ///
	label(4 "Other") ///
	rows(1) size(small) symxsize(vsmall) symysize(vsmall) 						///
	ring() position() region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) 	///
graphregion(fcolor()) plotregion(style(none)) ///
saving("`out'/hr - s3 f8b.gph", replace)

import excel "`base'/wp-f16-f23.xlsx", ///
	sheet("Investment Fund Assets, Chart") cellrange(D16:I26) firstrow clear
* destring *, replace
foreach var of varlist 	Equity-Other {
	replace `var' = 100*`var'
	}
outsheet using "`out'/wp-f23c.txt", replace	

graph bar (asis)  Equity-Other, 		///
over(cname, sort(Equity) descending label(labsize(small) angle(h)))					///
stack 																		///
bar(1, bstyle(p1bar))														///
bar(2, bstyle(p2bar))														///
bar(3, bstyle(p3bar))														///
bar(4, bstyle(p4bar))														///
bar(5, bstyle(p7bar))														///
blabel(bar, format(%2.0f) position(center) color(white) size(vsmall))		///
title("Investment Funds", span ring(7) position() size(*0.8)) 			///
ylabel(, format(%9.0fc) ang(h) gstyle(major) glcolor(gs12))						///
legend(order(1 2 3 4 5) 												///
	label(1 "Equity") label(2 "Debt") label(3 "Mixed") ///
	label(4 "Money mkt") label(4 "Other") ///
	rows(1) size(small) symxsize(vsmall) symysize(vsmall) 						///
	ring() position() region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) ///
graphregion(fcolor()) plotregion(style(none)) ///
saving("`out'/hr - s3 f8c.gph", replace)


local filelist : dir "`out'"  files "hr - s3 f8*.gph"
cd "`out'"  // otherwise the next command does not work
graph combine `filelist',													///
cols(1) rows(3) 															///
ysize(9) xsize(6) 															///
title("Figure 23. Investment Portfolios of NBFIs", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:Percent of total AUM, end 2011})", 								///
	span ring(6) position(11) size(small)) 									///
note("Notes: 1/ Financial intermediation are assets held by insurance companies related to loans," ///
"including loans guaranteed by mortgages." ///
"Sources: National authorities and authors' calculations.", size(vsmall) span)														///
plotregion(style()) graphregion(fcolor())
graph export "`out'/wp-f23.png", width(2500) replace

* clean garbage
local filelist : dir "`out'" files "hr - s3 f8*.gph"
foreach file of local filelist {
	erase "`out'/`file'"
}

